==> tdm_2.1.1.tar.gz: tdm/R/all.Amianhinfusionsm.R <==
all.Amianhinfusionsm<-function(){
     cat("\n")                                                                       
     cat("-----------------------------------------------------------------------\n")
     cat("    --Aminophylline anhydrous iv infusion input data information--     \n")
     note_for_Thesm_conc_input()
     cat("-----------------------------------------------------------------------\n")                                                      
     cat("\n")
     note_for_close_window()
     AmianhinfusionSMMpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","DL (mg)","tinf (hr)","R (mg/hr)"),value=c(0))
     AmianhinfusionSMMpar<-edit(AmianhinfusionSMMpar)
     AmianhinfusionSMMpar<-ycheck(AmianhinfusionSMMpar)
     cat("\n")
     cat("------------------------------------------------------------------------\n")
     cat("    --Aminophylline anhydrous iv infusion input data information--      \n")
     note_for_Theinfusionsm_input()
     cat("------------------------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     AmianhinfusionSMpar<-data.frame(ts=c(0),conc=c(0))                                                                                                                            
     AmianhinfusionSMpar<-edit(AmianhinfusionSMpar)                                            
     AmianhinfusionSMpar<-mscheck(AmianhinfusionSMpar)                                         
     cat("\n")
     Amianhinfusion.sm(length(AmianhinfusionSMpar$ts),AmianhinfusionSMpar$conc,AmianhinfusionSMpar$ts,AmianhinfusionSMMpar[3,2],AmianhinfusionSMMpar[2,2],AmianhinfusionSMMpar[5,2],AmianhinfusionSMMpar[1,2],AmianhinfusionSMMpar[4,2],AmianhinfusionSMMpar[6,2],AmianhinfusionSMMpar[8,2],AmianhinfusionSMMpar[7,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("------------------------------------------------------------------------\n")
     cat("   --Aminophylline anhydrous iv infusion output data information--      \n")
     note_for_Theinfusionsm_output()
     cat("------------------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n")
     C<-0.85*AmianhinfusionSMMpar[8,2]/(samplesStats("cl"))
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     show(coutput)     
     cat("\n")   
     Amianhinfusion.more()                                  
}

==> tdm_2.2.2.tar.gz: tdm/R/all.Amianhinfusionsm.R <==
all.Amianhinfusionsm<-function(){
     cat("\n")                                                                       
     cat("-----------------------------------------------------------------------\n")
     cat("    --Aminophylline anhydrous iv infusion input data information--     \n")
     note_for_Thesm_conc_input()
     cat("-----------------------------------------------------------------------\n")                                                      
     cat("\n")
     note_for_close_window()
     AmianhinfusionSMMpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","DL (mg)","tinf (hr)","R (mg/hr)"),value=c(0))
     AmianhinfusionSMMpar<-edit(AmianhinfusionSMMpar)
##     AmianhinfusionSMMpar<-ycheck(AmianhinfusionSMMpar)
     cat("\n")
     cat("------------------------------------------------------------------------\n")
     cat("    --Aminophylline anhydrous iv infusion input data information--      \n")
     note_for_Theinfusionsm_input()
     cat("------------------------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     AmianhinfusionSMpar<-data.frame(ts=c(0),conc=c(0))                                                                                                                            
     AmianhinfusionSMpar<-edit(AmianhinfusionSMpar)                                            
     AmianhinfusionSMpar<-mscheck(AmianhinfusionSMpar)                                         
     cat("\n")
     Amianhinfusion.sm(length(AmianhinfusionSMpar$ts),AmianhinfusionSMpar$conc,AmianhinfusionSMpar$ts,AmianhinfusionSMMpar[3,2],AmianhinfusionSMMpar[2,2],AmianhinfusionSMMpar[5,2],AmianhinfusionSMMpar[1,2],AmianhinfusionSMMpar[4,2],AmianhinfusionSMMpar[6,2],AmianhinfusionSMMpar[8,2],AmianhinfusionSMMpar[7,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("------------------------------------------------------------------------\n")
     cat("   --Aminophylline anhydrous iv infusion output data information--      \n")
     note_for_Theinfusionsm_output()
     cat("------------------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n")
     C<-0.85*AmianhinfusionSMMpar[8,2]/(samplesStats("cl"))
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     show(coutput)     
     cat("\n")   
     Amianhinfusion.more()                                  
}
